@@ -88,12 +88,7 @@ class ZoomAPIClient(object):
                     return response.content
 
         else:
-            if "message" in response.json():
-                raise ZoomAPIError(response.json()["message"])
-            else:
-                raise ZoomAPIError(
-                    f"Received status code {response.status_code} on {response.url}"
-                )
+            raise ZoomAPIError(response.text)
 
     def get(
         self,
@@ -202,6 +197,12 @@ class ZoomAPIClient(object):
         )
         return self.parse_request_response(response)
 
+    def put(self, endpoint_url: str, params: dict = None, data: dict = None):
+        response = self._session.put(
+            f"{self._server}{endpoint_url}", params=params, json=data
+        )
+        return self.parse_request_response(response)
+
     def delete(self, endpoint_url: str):
         response = self._session.delete(f"{self._server}{endpoint_url}")
         return self.parse_request_response(response)
